summaryrefslogtreecommitdiff
path: root/plugins/yaml/node.h
diff options
context:
space:
mode:
authorCyrille Bagard <nocbos@gmail.com>2019-11-03 22:56:52 (GMT)
committerCyrille Bagard <nocbos@gmail.com>2019-11-03 22:56:52 (GMT)
commit459b345d69532825f21bdcd3e4f92009b0a046dc (patch)
treee0bc3d9089f0b5452e77be0f5d37fc0522f78c4a /plugins/yaml/node.h
parent33b5dc9af0404eabeb0e60245ab1ca1dc3713a17 (diff)
Handled sequences with the Yaml reader in an improved way.
Diffstat (limited to 'plugins/yaml/node.h')
-rw-r--r--plugins/yaml/node.h18
1 files changed, 12 insertions, 6 deletions
diff --git a/plugins/yaml/node.h b/plugins/yaml/node.h
index 582fa58..f1bbb23 100644
--- a/plugins/yaml/node.h
+++ b/plugins/yaml/node.h
@@ -32,6 +32,9 @@
#include "line.h"
+/* Depuis collection.h : collection de noeuds au format Yaml (instance) */
+typedef struct _GYamlCollection GYamlCollection;
+
#define G_TYPE_YAML_NODE g_yaml_node_get_type()
#define G_YAML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), G_TYPE_YAML_NODE, GYamlNode))
@@ -57,14 +60,17 @@ GYamlNode *g_yaml_node_new(GYamlLine *);
/* Fournit la ligne principale associée à un noeud. */
GYamlLine *g_yaml_node_get_yaml_line(const GYamlNode *);
-/* Ajoute un noeud à un noeud d'une arborescence Yaml. */
-void g_yaml_node_add_child(GYamlNode *, GYamlNode *);
+/* Attache une collection de noeuds Yaml à un noeud. */
+void g_yaml_node_set_collection(GYamlNode *, GYamlCollection *);
+
+/* Fournit une éventuelle collection rattachée à un noeud. */
+GYamlCollection *g_yaml_node_get_collection(const GYamlNode *);
-/* Fournit la liste des noeuds intégrés dans un noeud Yaml. */
-GYamlNode **g_yaml_node_get_children(const GYamlNode *, size_t *);
+/* Recherche les noeuds correspondant à un chemin. */
+void _g_yaml_node_find_by_path(GYamlNode *, const char *, GYamlNode ***, size_t *);
-/* Recherche le noeud correspondant à un chemin. */
-GYamlNode *g_yaml_node_find_node_by_path(GYamlNode *, const char *);
+/* Recherche les noeuds correspondant à un chemin. */
+void g_yaml_node_find_by_path(GYamlNode *, const char *, GYamlNode ***, size_t *);